@@ -6,8 +6,8 @@
 #'
 #' @return `scto_meta()` returns a nested list of metadata related to forms,
 #'   datasets, groups, and publishing information. `scto_catalog()` returns a
-#'   `data.table` with columns `type` ("form" or "dataset"), `id`, `title`, and
-#'   version.
+#'   `data.table` with columns `type` ("form" or "dataset"), `id`, `title`,
+#'   `version`, `group_id`, and `group_title`.
 #'
 #' @examples
 #' \dontrun{
@@ -36,7 +36,7 @@ scto_meta = function(auth) {
   scto_bullets(
     c(v = 'Reading metadata for server `{.server {auth$servername}}`.'))
   m = content(res, as = 'parsed')
-  return(m)
+  m
 }
 
 
@@ -46,14 +46,20 @@ scto_catalog = function(auth) {
   m = scto_meta(auth)
   # surveycto enforces uniqueness of IDs across forms and datasets
   types = c('datasets', 'forms')
-  func = function(x) x[c('id', 'title', 'version')]
+  func = \(x) x[c('id', 'title', 'version', 'groupId')]
   d = cbind(
     data.table(type = rep(
       substr(types, 1, nchar(types) - 1), times = lengths(m[types]))),
     rbindlist(
-      lapply(types, function(type) rbindlist(lapply(m[[type]], func)))))
+      lapply(types, \(type) rbindlist(lapply(m[[type]], func)))))
   # form versions come back as string, too big for int, so make numeric
   set(d, j = 'version', value = as.numeric(d$version))
+  setnames(d, 'groupId', 'group_id')
+
+  group_cols = c('group_id', 'group_title')
+  g = rbindlist(lapply(m$groups, \(x) x[c('id', 'title')]))
+  setnames(g, group_cols)
+  d = merge(d, g, by = group_cols[1L], sort = FALSE)
+  data.table::setcolorder(d, 2:5)
   data.table::setkey(d)
-  return(d)
 }
