@@ -11,7 +11,8 @@ if (Sys.getenv('SCTO_AUTH') == '') {
   auth_file = 'scto_auth.txt'
 } else {
   auth_file = withr::local_tempfile(.local_envir = teardown_env())
-  writeLines(Sys.getenv('SCTO_AUTH'), auth_file)}
+  writeLines(Sys.getenv('SCTO_AUTH'), auth_file)
+}
 
 auth_args = readLines(auth_file)
 
@@ -19,4 +20,5 @@ if (Sys.getenv('SCTO_PRIVATE_KEY') == '') {
   private_key = 'rsurveycto-private-key.pem'
 } else {
   private_key = withr::local_tempfile(.local_envir = teardown_env())
-  writeLines(Sys.getenv('SCTO_PRIVATE_KEY'), private_key)}
+  writeLines(Sys.getenv('SCTO_PRIVATE_KEY'), private_key)
+}
